%global soname 0
%global _version 0.3.3

Name:           fife
Epoch:          2
Version:        %{_version}r3
Release:        12%{?dist}
Summary:        Cross platform game creation framework
Group:          Amusements/Games
License:        LGPLv2+
URL:            http://www.fifengine.de
# https://sourceforge.net/projects/fife/files/active/src/fife-0.3.3r3.tar.gz/download
# removed ext/   -  removed for using system libs instead of shipped
# removed tests/   -  removed for legal issues
# removed tools/   -  removed for legal issues
# %{name}-dont-build-ext-and-tests.patch - dont build tests/ and ext/. Tools
# should be able to clear out licensing now and introduce a BSD License. We're
# not building it currently. Requires legal validation
Source0:        %{name}_%{version}-clean.tar.gz
Patch99:        %{name}-dont-build-ext-and-tests.patch

BuildRequires:  boost-devel
BuildRequires:  chrpath
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  guichan-devel
BuildRequires:  libpng-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libXcursor-devel
BuildRequires:  mesa-libGLU-devel
BuildRequires:  openal-devel
BuildRequires:  python-devel
BuildRequires:  scons
BuildRequires:  SDL-devel
BuildRequires:  SDL_ttf-devel
BuildRequires:  SDL_image-devel
BuildRequires:  swig
BuildRequires:	tinyxml-devel
BuildRequires:  zlib-devel

Requires:	python-%{name} = %{epoch}:%{version}-%{release}

%description
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides you with the ability to create a
game using Python interfaces.

This package provides the FIFE shared object libraries.

%package  devel
Summary:  FIFE Engine development files
Group:    Development/Libraries
Requires: %{name} = %{epoch}:%{version}-%{release}

%description devel
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides you with the ability to create a
game using Python interfaces.

This package provides the development files for FIFE.

%package -n python-%{name}
Summary:        FIFE engine python bindings
Group:          Amusements/Games

%description -n python-%{name}
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides you with the ability to create a
game using Python interfaces.

This package provides the Python game-engine. 

%package doc
Summary:       FIFE Engine bundled documentation
Group:         Documentation
BuildRequires: doxygen
BuildArch:     noarch
Requires:      %{name} = %{epoch}:%{version}-%{release}

%description doc
Doxygen generated documentation for %{name}. 

%prep
%setup -q -n %{name}_%{version}
%patch99 -p1 -b .clean

# be utf-8 clean, dudes!
for f in ./AUTHORS ./CHANGES ./COPYING ./README
do
 iconv -f iso-8859-1 -t utf-8 $f |sed 's|\r||g' > $f.utf8
 touch -c -r $f $f.utf8
 mv $f.utf8 $f
done 

%build
scons . \
      CXXFLAGS='%{optflags}' \
      --enable-debug \
      --enable-rend-grid \
      --enable-rend-camzone \
      --prefix=%{_prefix} \
      --python-prefix=%{python_sitearch} \
      fife-shared fife-python fife-swig

# Doxygen generated docs
doxygen ./doc/doxygen/doxyfile
rm -f ./doc/doxygen/html/installdox


%install
rm -rf %{buildroot}

scons . \
      DESTDIR=%{buildroot} \
      CXXFLAGS='%{optflags}' \
      --enable-rend-grid \
      --enable-rend-camzone \
      --enable-debug \
      --prefix=%{_prefix} \
      --lib-dir=%{buildroot}%{_libdir} \
      --python-prefix=%{python_sitearch} \
      install-all

# playing a little bit with soname
pushd %{buildroot}%{_libdir}
ln -s lib%{name}.so.%{_version} lib%{name}.so.%{soname}
ln -s lib%{name}.so.%{_version} lib%{name}.so
popd

# rpath is evil, evil, evil
chrpath --delete %{buildroot}%{_libdir}/lib%{name}.so
chrpath --delete %{buildroot}%{python_sitearch}/%{name}/_%{name}.so

# dont package static blobs, does anyone really use it?
find %{buildroot}%{_libdir} -type f -name "*.a" -delete -print

mkdir -p %{buildroot}/%{_bindir}/
cat > %{buildroot}/%{_bindir}/%{name}-documentation << EOF
#!/bin/sh
xdg-open file://%{_pkgdocdir}-doc/index.html
EOF
chmod +x %{buildroot}/%{_bindir}/%{name}-documentation

# fife.ppc: E: non-standard-executable-perm /usr/lib/libfife.so.0 0775
chmod 755 %{buildroot}/%{_libdir}/lib%{name}.so.%{soname}
# fife.ppc: E: non-standard-executable-perm /usr/lib/python2.6/site-packages/fife/_fife.so 0775
chmod 755 %{buildroot}/%{python_sitearch}/%{name}/_%{name}.so

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc AUTHORS CHANGES COPYING README
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}.so.%{soname}
%{_libdir}/lib%{name}.so.%{_version}

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so

%files doc
%doc ./doc/doxygen/html/*
%{_bindir}/%{name}-documentation

%files -n python-%{name}
%doc AUTHORS CHANGES COPYING README
%{python_sitearch}/%{name}/


%changelog
* Mon Jan 26 2015 Petr Machata <pmachata@redhat.com> - 2:0.3.3r3-12
- Rebuild for boost 1.57.0

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2:0.3.3r3-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2:0.3.3r3-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 22 2014 Petr Machata <pmachata@redhat.com> - 2:0.3.3r3-9
- Rebuild for boost 1.55.0

* Tue Aug 06 2013 Simon Dietz <cassmodiah@fedoraproject.org> -  2:0.3.3r3-8
- Fix RHBZ#993751

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2:0.3.3r3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 pmachata@redhat.com - 2:0.3.3r3-6
- Rebuild for boost 1.54.0

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 2:0.3.3r3-5
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 2:0.3.3r3-4
- Rebuild for Boost-1.53.0

* Sun Aug 12 2012 Kevin Fenzi <kevin@scrye.com> - 2:0.3.3r3-3
- Rebuild for new boost

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2:0.3.3r3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu May 10 2012 Tom Callaway <spot@fedoraproject.org> - 2:0.3.3r3-1
- update to 0.3.3r3
- merge most of nmarques's changes

* Tue Mar 20 2012 Jon Ciesla <limburgher@gmail.com> - 1:0.3.2-13.r2
- guichan rebuild.

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2:0.3.2-12.r2
- Rebuilt for c++ ABI breakage

* Mon Jan 20 2012 Bruno Wolff III <bruno@wolff.to> - 1:0.3.2-11.r2
- Fix for gcc 4.7

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2:0.3.2-10.r2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Nov 20 2011 Bruno Wolff III <bruno@wolff.to> - 1:0.3.2-9.r2
- Rebuild for boost soname bump

* Sun Nov 06 2011 Bruno Wolff III <bruno@wolff.to> - 1:0.3.2-8.r2
- Rebuild for libpng 1.5

* Tue Aug 02 2011 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.2-7.r2
- Rebuild for different dependencies

* Fri Jul 22 2011 Bruno Wolff III <bruno@wolff.to> - 1:0.3.2-6.r2
- Rebuild for boost 1.47

* Thu Jun 02 2011 Bruno Wolff III <bruno@wolff.to> - 1:0.3.2-5.r2
- Rebuild for guichan 0.8.2 soname bump

* Mon Apr 18 2011 Tom Callaway <spot@fedoraproject.org> - 1:0.3.2-4.r2
- update to 0.3.2r2

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Feb 06 2011 Thomas Spura <tomspur@fedoraproject.org> - 1:0.3.2-2
- rebuild for new boost

* Fri Nov 26 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.2-1
- Update to 0.3.2

* Wed Aug  4 2010 Thomas Spura <tomspur@fedoraproject.org> - 1:0.3.1-4
- Rebuilt for http://fedoraproject.org/wiki/Features/F14Boost144
- install to sitearch not sitelib
- properly use parallel make

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1:0.3.1-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Thu Apr 29 2010 Thomas Spura <tomspur@fedoraproject.org> - 1:0.3.1-2
- also link against boost_filesystem

* Wed Apr 07 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.1-1
- Update to 0.3.1
 
* Tue Mar 09 2010 Thomas Kowaliczek <linuxdonald@linuxdonald.de> - 1:0.3.0-4
- Fixed Bug #564752
- Thanks for the patch Terje

* Mon Feb 01 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.0-3
- Cosmetical Issues

* Sun Jan 31 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.0-2
- Split devel package and add a static subpackage
- Generate doxygen docs and add a doc subpackage
- Correct epoch usage
- Create and use soname
- Honor CFLAGS
- Correct leaf
- Cleanup

* Wed Jan 27 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.0-1
- Update to 0.3.0

* Tue Jan 21 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.28.r3111svn
- Rebuild for updated boost

* Sat Dec 12 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.27.r3111svn
- Update to r3111

* Thu Oct 08 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.26.r3056svn
- There are no errors revoked spec changes!

* Thu Oct 08 2009 Thomas Kowaliczek <linuxdonald@linuxdonald.de> - 2009.0-0.25.r3056svn
- Update to r3056 and fixed some spec errors

* Tue Sep 29 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.24.r3054svn
- Update to r3054

* Mon Sep 28 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.23.r3053svn
- Update to r3053

* Mon Sep 28 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.22.r3052svn
- Update to r3052

* Sun Sep 27 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.21.r3051svn
- Update to r3051

* Fri Sep 25 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.20.r3050svn
- Update to r3050

* Wed Sep 23 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.19.r3049svn
- Update to r3049

* Tue Sep 22 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.18.r3048svn
- Update to r3048

* Mon Sep 21 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.17.r3047svn
- Update to r3047

* Mon Sep 21 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.16.r3046svn
- Update to r3046

* Mon Sep 21 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.15.r3045svn
- Update to r3045

* Thu Aug 20 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.14.r2955svn
- Update to r2955
- Honor OPTFLAGS

* Sat Jul 11 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.13.r2954svn
- Update to r2954
- Link follow files, because they are equal
   LIBDIR/NAME/engine/libNAME.so
   LIBDIR/NAME/engine/swigwrappers/python/_NAME.so

* Fri Jul 10 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.12.r2953svn
- Update to r2953
- Remove all outcommented spec-code

* Fri Jul 10 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.11.r2952svn
- Correct rpath in source instead of binary

* Fri Jul 10 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.10.r2952svn
- Update to r2952
- Remove ldconfig from POST and POSTUN
- Correct license to LGPLv2+

* Wed Jul 08 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.9.r2951svn
- Update to r2951

* Wed Jul 08 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.8.r2947svn
- Remove tests and clients from source0 for legal issues
- Remove ext from source0 instead of remove via 'rm' in spec - to proof that there is no internal shipped dependency in build process
- Remove doc subpackage

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.7.r2947svn
- Update to r2947

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.6.r2946svn
- Update to r2946

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.5.r2945svn
- Update to r2945

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.4.r2944svn
- Making RPMLINT happy
- Correct file permissions and add missed shebangs

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.3.r2944svn
- Update to r2944

* Sat Jun 13 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.2.r2916svn
- Update to r2916

* Sun Mar 29 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.1.r2761svn
- Initial release
